@import 'orchestra/static/orchestra/common/css/common.scss';
@import 'orchestra/static/orchestra/common/css/base';

$task-card-height: 8.5rem;
$task-card-padding: 1rem;
$task-card-margin-bottom: 1.5rem;

// TODO(jrbotros): use variable from bootstrap-sass?
$bootstrap-md: "(min-width: 992px)";

// TODO(marcua): Move this to tasktable.scss
.tasks-section {
  .section-header {
    .warning-message {
      font-style: italic;
      margin-left: 1.5rem;
      font-size: 1.5rem;
    }

    // New task buttons
    .btn-new-task {
      width: 150px;
      margin: 0 5px;
    }
    .btn-new-entry-task {
      @extend .btn-new-task;
      background-color: $dark-green;
      &.disabled {
        background-color: rgba($dark-green, 0.6);
      }
    }
    .btn-new-review-task {
      @extend .btn-new-task;
      background-color: $light-green;
      &.disabled {
        background-color: rgba($light-green, 0.6);
      }
    }
  }
  tr.task-row {
    cursor: pointer;
  }
  .table {
    margin-bottom: 0;
    font-size: 1.4rem;
  }
}
